==> wisteria-0.5.0.tgz: package/README.md <==
# wisteria [![Build Status](https://travis-ci.org/t32k/wisteria.svg)](https://travis-ci.org/t32k/wisteria) [![wercker status](https://app.wercker.com/status/fff7cc4c5446d5b16065e8f93a79309e/s/master "wercker status")](https://app.wercker.com/project/bykey/fff7cc4c5446d5b16065e8f93a79309e)

wisteria.css is a class-attribute based harmless CSS library.

+ __Harmless__: wisteria dose not destroy your web page, because have almost class selector style.
+ __Helper__:  wisteria has a bunch of [Emmet](http://docs.emmet.io/cheat-sheet/)-like utility classes.
+ __Hi-Speed__: You can make a mock-up site rapidly.

## Install

+ __Bower:__ `bower install --save wisteria`
+ __npm:__ `npm install --save wisteria`
+ __Download:__ [zip](https://github.com/t32k/wisteria/archive/master.zip)

## Getting started

Include the wisteria.css and [HTML5-Rest](https://github.com/murtaugh/HTML5-Reset).css files in your site.

```html
<link rel="stylesheet" href="css/html5-reset.css">
<link rel="stylesheet" href="css/wisteria.css">
```

## Browser Support

+ Google Chrome (latest)
+ Mozilla Firefox (latest)
+ Internet Explorer (latest)
+ Opera (latest)
+ Apple Safari (latest)

## License

The MIT License (MIT)

Copyright (c) 2015 Koji Ishimoto

Permission is hereby granted, free of charge, to any person obtaining a copy of
this software and associated documentation files (the "Software"), to deal in
the Software without restriction, including without limitation the rights to
use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
the Software, and to permit persons to whom the Software is furnished to do so,
subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

==> wisteria-0.6.0.tgz: package/README.md <==
# Wisteria [![Build Status](https://travis-ci.org/t32k/wisteria.svg)](https://travis-ci.org/t32k/wisteria) [![wercker status](https://app.wercker.com/status/fff7cc4c5446d5b16065e8f93a79309e/s/master "wercker status")](https://app.wercker.com/project/bykey/fff7cc4c5446d5b16065e8f93a79309e)

Wisteria.css is a class selectors based harmless CSS library.

+ __Harmless__: Wisteria dose not destroy your web page style, because has only class selectors. HTML5-Rest just reset the style.
+ __Helper__: Wisteria has a bunch of Emmet-like utility classes. It means you do not have to learn the namig rules.
+ __Hi-Control__: Wisteria's grid implements simple and modern Flexbox layout, so you make a mockup site with less typing rapidly.

## Install

+ __Bower:__ `bower install --save wisteria`
+ __npm:__ `npm install --save wisteria`
+ __Download:__ [zip](https://github.com/t32k/wisteria/archive/master.zip)

## Getting started

Include the wisteria.css and [HTML5-Rest](https://github.com/murtaugh/HTML5-Reset).css files in your site.

```html
<link rel="stylesheet" href="css/html5-reset.css">
<link rel="stylesheet" href="css/wisteria.css">
```

## Browser Support

+ Google Chrome (latest)
+ Mozilla Firefox (latest)
+ Apple Safari (latest)
+ Opera (latest)
+ Internet Explorer (latest) maybe...

## License

The MIT License (MIT)

Copyright (c) 2015 Koji Ishimoto

Permission is hereby granted, free of charge, to any person obtaining a copy of
this software and associated documentation files (the "Software"), to deal in
the Software without restriction, including without limitation the rights to
use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
the Software, and to permit persons to whom the Software is furnished to do so,
subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
